#! /usr/bin/python
from time import time
import sys, os, os.path

print "Usage %s [comprehensive|modest] (specifying nothing means quick test)" % sys.argv[0]
print "Time to import lib:",
s = time()
from oops import *
d = time()-s
print "%0.4f" % d


testfile = "bench_file.odb"
if os.path.exists(testfile):
	os.remove(testfile)
	print "deleted stale test db file"


def DictBenchmark(dict, rounds):
	print "Creating Dict with %d items:"%rounds,
	s = time()
	for i in xrange(rounds):
		dict[i] = i
	d = time()-s
	print "%0.4f (%0.2f items/second)" % (d, rounds/d)

	print "Modifying %d values within the Dict:"%rounds,
	s = time()
	for i in xrange(rounds):
		dict[i] = i
	d = time()-s
	print "%0.4f (%0.2f items/second)" % (d, rounds/d)

	print "Deleting %d values from the Dict:"%rounds,
	s = time()
	for i in xrange(rounds):
		del dict[i]
	d = time()-s
	print "%0.4f (%0.2f items/second)" % (d, rounds/d)


def ListBenchmark(list, rounds):
	print "Creating List with %d items:"%rounds,
	s = time()
	for i in xrange(rounds):
		list.append(i)
	d = time()-s
	print "%0.4f (%0.2f items/second)" % (d, rounds/d)

	print "Modifying %d values within the List"%rounds,
	s = time()
	for i in xrange(rounds):
		list[i] = i
	d = time()-s
	print "%0.4f (%0.2f items/second)" % (d, rounds/d)

	print "Popping %d values from the List"%rounds,
	s = time()
	for i in xrange(rounds):
		list.pop()
	d = time()-s
	print "%0.4f (%0.2f items/second)" % (d, rounds/d)


comprehensive = [10, 50, 100, 500, 1000, 5000, 10000, 25000, 50000, 75000, 100000, 250000, 500000, 750000, 1000000]
modest = [10, 100, 1000, 10000, 25000, 50000, 100000]
quick = [10, 100, 1000, 2500, 5000, 7500, 10000]


sizes = quick
if len(sys.argv)>1:
	if sys.argv[1]=="comprehensive":
		sizes = comprehensive
	elif sys.argv[1]=="modest":
		sizes = modest


print "Obj Tests"
class Person(Obj):
	text = Text()
	data = Data()
	int = Int()
	float = Float()
	type = Type()

p = Person()
def BenchWriteUnits(obj, attrname, value):
	s = time()
	for i in range(10000):
		setattr(obj, attrname, value)
	return time() - s

def BenchReadUnits(obj, attrname):
	s = time()
	for i in range(10000):
		getattr(obj, attrname)
	return time() - s

tests = {"text":u"value", "data":"value", "int":0, "float":0.0, "type":Person}
for i in tests:
	d = BenchWriteUnits(p, i, tests[i])
	print "Assignment to %s: %0.4f secs (%0.2f times/sec)"%(type(getattr(Person, i)).__name__, d, 10000/d)
	d = BenchReadUnits(p, i)
	print "Retrieval from %s: %0.4f secs (%0.2f times/sec)"%(type(getattr(Person, i)).__name__, d, 10000/d)



print "Dict Tests"
for i in sizes:
	print "\n[On Disk]\n---------"
	try:
		DictBenchmark(Dict(filename=testfile), i)
	finally:
		os.remove(testfile)

	print "\n[In Memory]\n-----------"
	DictBenchmark(Dict(), i)


print "List Tests"
for i in sizes:
	print "\n[On Disk]\n---------"
	try:
		ListBenchmark(List(filename=testfile), i)
	finally:
		os.remove(testfile)
	print "\n[In Memory]\n-----------"
	ListBenchmark(List(), i)
