from alltests import *
from oops import *


class AddTests(TestCase):
	def runTest(self):
		dbdict = {}
		for i in range(1000):
			node = Node(database=dbdict)
			keyspace = node.keyspace = Keyspace()
			keyspace.add_key(i)

		self.failUnless(len(keyspace)==1000, "keyspace did not load correctly")
		for i in range(1000):
			if not i in keyspace:
				self.fail("missing key %s" % i)

				
class CopyTests(TestCase):
	def runTest(self):
		node = Node()
		keyspace = node.keyspace = Keyspace()
		for i in range(1000):
			keyspace.add_key(i)

		node.copy = node.keyspace # copy the keyspace
		keyspace = node.copy

		self.failUnless(len(keyspace)==1000, "keyspace did not load correctly")
		for i in range(1000):
			if not i in keyspace:
				self.fail("missing key %s" % i)


class DeleteTests(TestCase):
	def runTest(self):
		dbdict = {}
		node = Node(database=dbdict)
		keyspace = node.keyspace = Keyspace()
		for i in range(1000):
			keyspace.add_key(i)

		keys = keyspace[:]
		for key in iter(keys):
			node = Node(database=dbdict)
			keyspace = node.keyspace = Keyspace()
			keyspace.rem_key(key)

		self.failUnless(len(keyspace)==0, "items in keyspace were not all deleted")


class ClearTests(TestCase):
	def runTest(self):
		dbdict = {}
		node = Node(database=dbdict)
		keyspace = node.keyspace = Keyspace()
		for i in range(1000):
			keyspace.add_key(i)
		del node.keyspace
		for i in dbdict.keys():
			self.failIf(i[0]=="keyspace", "keyspace was not completely cleared")


KeyspaceSuite = TestSuite([AddTests(), CopyTests(), DeleteTests(), ClearTests()])
testsuites.append(KeyspaceSuite)
